#
# spec file for package python-argon2-cffi
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_without python2
Name:           python-argon2-cffi
Version:        19.2.0
Release:        150200.3.2.1
Summary:        The Argon2 password hashing algorithm for Python
License:        MIT
URL:            https://github.com/hynek/argon2_cffi
Source:         https://files.pythonhosted.org/packages/source/a/argon2-cffi/argon2-cffi-%{version}.tar.gz
BuildRequires:  %{python_module cffi >= 1.0.0}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module hypothesis}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools >= 6.0}
BuildRequires:  %{python_module six}
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(libargon2)
Requires:       python-cffi >= 1.0.0
Requires:       python-six
Provides:       python-argon2_cffi
Obsoletes:      python-argon2_cffi
%if %{with python2}
BuildRequires:  python-enum34
%endif
%ifpython2
Requires:       python-enum34
%endif
%python_subpackages

%description
A Python module that uses CFFI to access the Argon2 password hashing
C library.

%prep
%setup -q -n argon2-cffi-%{version}

%build
export ARGON2_CFFI_USE_SYSTEM=1
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
# test_argument_ranges - randomly fails
%pytest_arch -k 'not test_argument_ranges'

%files %{python_files}
%doc README.rst CHANGELOG.rst FAQ.rst
%license LICENSE
%{python_sitearch}/*

%changelog
* Mon Mar 16 2020 tchvatal@suse.com
- Fix build without python2
* Fri Jan 17 2020 mcalabkova@suse.com
- update to 19.2.0
  * Python 3.4 is not supported anymore.
  * The dependency on enum34 is now protected using a PEP 508 marker.
* Tue Jun  4 2019 tchvatal@suse.com
- Skip test that randomly fails in obs test_argument_ranges
* Mon Apr  1 2019 tchvatal@suse.com
- Provide argon2_cffi namespace too
* Tue Feb 19 2019 jayvdb@gmail.com
- Update to v19.1.0
  * Vendoring Argon2 @ 670229c
  * Added support for Argon2 v1.2 hashes in argon2.extract_parameters()
- from 18.3.0
  * Vendoring Argon2 @ 670229c
  * argon2.PasswordHasher's hash type is now configurable
- from 18.2.0
  * Vendoring Argon2 @ 670229c
  * The hash type for ``argon2.PasswordHasher`` is Argon2\ **id** now.
    This decision has been made based on the recommendations in the latest
    Argon2 RFC draft
  * To make the change of hash type backward compatible,
    argon2.PasswordHasher.verify() now determines the type of the hash and
    verifies it accordingly
  * Some of the hash parameters have been made stricter to be closer to said
    recommendations. The current goal for a hash verification times is around 50ms
  * To allow for bespoke decisions about upgrading Argon2 parameters, it's now
    possible to extract them from a hash via argon2.extract_parameters()
  * Additionally argon2.PasswordHasher now has a check_needs_rehash() method
    that allows to verify whether a hash has been created with the instance's
    parameters or whether it should be rehashed
* Wed Aug  8 2018 jengelh@inai.de
- Ensure neutrality of description.
* Wed Aug  8 2018 tchvatal@suse.com
- Do not use bundled argon2
* Wed Aug  8 2018 tchvatal@suse.com
- Initial package for v18.1.0, used by Django
